// AdvanceLcd
// Copyright  Christian Klaussner
// 
// advlcd.h

#define LCDCALL __stdcall

typedef void *LCDAPPLET;
typedef void *LCDPIXMAP;
typedef void *LCDFONT;

typedef int (LCDCALL *LCDEVENTHANDLER)(int nEvent, void *pContext, int nData);

#define LCD_OK							0
#define LCD_ERROR						1
#define LCD_ERROR_NOT_INITIALIZED		2
#define LCD_ERROR_INVALID_PARAMETER		3
#define LCD_ERROR_NOT_FOUND				4

#define LCD_DEVICE_INVALID	-1
#define LCD_DEVICE_MONO		1
#define LCD_DEVICE_COLOR	2

#define LCD_EVENT_CONFIGURE	1
#define LCD_EVENT_BUTTON	2

#define LCD_BUTTON_1		0x0001
#define LCD_BUTTON_2		0x0002
#define LCD_BUTTON_3		0x0004
#define LCD_BUTTON_4		0x0008

#define LCD_BUTTON_LEFT		0x0100
#define LCD_BUTTON_RIGHT	0x0200
#define LCD_BUTTON_OK		0x0400
#define LCD_BUTTON_CANCEL	0x0800
#define LCD_BUTTON_UP		0x1000
#define LCD_BUTTON_DOWN		0x2000
#define LCD_BUTTON_MENU		0x4000

#define LCD_PRIORITY_LOW		1
#define LCD_PRIORITY_NORMAL		2
#define LCD_PRIORITY_HIGH		3

#define LCD_COLOR_VISIBLE		0xFFFFFF
#define LCD_COLOR_INVISIBLE		0

#define LCD_FONT_DEFAULT	0
#define LCD_FONT_BOLD		1
#define LCD_FONT_ITALIC		2
#define LCD_FONT_UNDERLINE	4

#ifdef __cplusplus
extern "C"
{
#endif

int LCDCALL LcdInitialize();
int LCDCALL LcdDeInitialize();
int LCDCALL LcdLastError();

LCDAPPLET LCDCALL LcdCreateAppletA(const char *pName, int nDevices, int bConfigurable, int bAutostart);
LCDAPPLET LCDCALL LcdCreateAppletW(const wchar_t *pName, int nDevices, int bConfigurable, int bAutostart);
#ifdef UNICODE
#define LcdCreateApplet LcdCreateAppletW
#else
#define LcdCreateApplet LcdCreateAppletA
#endif
int LCDCALL LcdDeleteApplet(LCDAPPLET pApplet);
int LCDCALL LcdAppletEnabled(LCDAPPLET pApplet);
int LCDCALL LcdAppletOpened(LCDAPPLET pApplet);
int LCDCALL LcdAppletActive(LCDAPPLET pApplet);
int LCDCALL LcdWaitActivation(LCDAPPLET pApplet);
int LCDCALL LcdSelectDevice(LCDAPPLET pApplet, int nDevice);
int LCDCALL LcdSetEventHandler(LCDAPPLET pApplet, LCDEVENTHANDLER pEventHandler, void *pContext);
int LCDCALL LcdButtonState(LCDAPPLET pApplet, int nButton);
int LCDCALL LcdConfigState(LCDAPPLET pApplet);
int LCDCALL LcdSetPriority(LCDAPPLET pApplet, int nPriority, int bForeground);
int LCDCALL LcdUpdate(LCDAPPLET pApplet, int bSync);

LCDPIXMAP LCDCALL LcdCreatePixmap(int nWidth, int nHeight, int nDevice);
LCDPIXMAP LCDCALL LcdLoadPixmapA(const char *pFile);
LCDPIXMAP LCDCALL LcdLoadPixmapW(const wchar_t *pFile);
#ifdef UNICODE
#define LcdLoadPixmap LcdLoadPixmapW
#else
#define LcdLoadPixmap LcdLoadPixmapA
#endif
LCDPIXMAP LCDCALL LcdLoadAnimPixmapA(const char *pFile, int nFrameWidth, int nFrameHeight, int nFrames);
LCDPIXMAP LCDCALL LcdLoadAnimPixmapW(const wchar_t *pFile, int nFrameWidth, int nFrameHeight, int nFrames);
#ifdef UNICODE
#define LcdLoadAnimPixmap LcdLoadAnimPixmapW
#else
#define LcdLoadAnimPixmap LcdLoadAnimPixmapA
#endif
int LCDCALL LcdDeletePixmap(LCDPIXMAP pPixmap);
int LCDCALL LcdPixmapWidth(LCDPIXMAP pPixmap);
int LCDCALL LcdPixmapHeight(LCDPIXMAP pPixmap);
int LCDCALL LcdDrawPixmap(LCDAPPLET pApplet, LCDPIXMAP pPixmap, int nX, int nY, int nFrame);
int LCDCALL LcdDrawPixmapRect(LCDAPPLET pApplet, LCDPIXMAP pPixmap, int nX, int nY, int nSx, int nSy, int nWidth, int nHeight, int nFrame);
int LCDCALL LcdSetTarget(LCDAPPLET pApplet, LCDPIXMAP pPixmap);
int LCDCALL LcdEnableAntiAlias(LCDAPPLET pApplet, int bEnable);
int LCDCALL LcdClear(LCDAPPLET pApplet, int nColor);
int LCDCALL LcdSetColor(LCDAPPLET pApplet, int nColor);
int LCDCALL LcdSetLineWidth(LCDAPPLET pApplet, float fWidth);
int LCDCALL LcdSetRotation(LCDAPPLET pApplet, float fRotation, int nCenterX, int nCenterY);
int LCDCALL LcdDrawLine(LCDAPPLET pApplet, int nX1, int nY1, int nX2, int nY2);
int LCDCALL LcdDrawRect(LCDAPPLET pApplet, int nX, int nY, int nWidth, int nHeight, int bFill);
int LCDCALL LcdDrawOval(LCDAPPLET pApplet, int nX, int nY, int nWidth, int nHeight, int bFill);

LCDFONT LCDCALL LcdLoadFontA(const char *pFamily, int nHeight, int nFlags, const char *pFile);
LCDFONT LCDCALL LcdLoadFontW(const wchar_t *pFamily, int nHeight, int nFlags, const wchar_t *pFile);
#ifdef UNICODE
#define LcdLoadFont LcdLoadFontW
#else
#define LcdLoadFont LcdLoadFontA
#endif
int LCDCALL LcdDeleteFont(LCDFONT pFont);
int LCDCALL LcdSetFont(LCDAPPLET pApplet, LCDFONT pFont);
int LCDCALL LcdDrawTextA(LCDAPPLET pApplet, const char *pString, int nX, int nY);
int LCDCALL LcdDrawTextW(LCDAPPLET pApplet, const wchar_t *pString, int nX, int nY);
#ifdef UNICODE
#define LcdDrawText LcdDrawTextW
#else
#define LcdDrawText LcdDrawTextA
#endif
int LCDCALL LcdStringWidthA(LCDAPPLET pApplet, const char *pString);
int LCDCALL LcdStringWidthW(LCDAPPLET pApplet, const wchar_t *pString);
#ifdef UNICODE
#define LcdStringWidth LcdStringWidthW
#else
#define LcdStringWidth LcdStringWidthA
#endif
int LCDCALL LcdStringHeightA(LCDAPPLET pApplet, const char *pString);
int LCDCALL LcdStringHeightW(LCDAPPLET pApplet, const wchar_t *pString);
#ifdef UNICODE
#define LcdStringHeight LcdStringHeightW
#else
#define LcdStringHeight LcdStringHeightA
#endif

#ifdef __cplusplus
}
#endif
